==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adreiça dau vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Minga de signatura non correspònde a aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vorgatz confirmar la vòstra signatura:',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un e-mail de confirmacion. Per validar la vòstra signatura, cau vesitar l’adreiça web mençonada per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bònjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornit li informacions seguenti :
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la vòstra signatura, basta de vos connectar a 
 l’adreiça çai sota (senon s’escamparà
 la vòstra demanda): 
    @url@


Mercé per la vòstra participacion
',
	'form_pet_message_commentaire' => 'Un messatge, una remarca?', # MODIF
	'form_pet_nom_site2' => 'Nom dau vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, li signaturas son temporàriament arrestadi.',
	'form_pet_signature_validee' => 'La vòstra signatura es validada. Mercé!',
	'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicada non es valida.',
	'form_pet_votre_email' => 'La vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Lo vòstre nom ò pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o podètz marcar çai sota',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Respòsta a l’article'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Minga de peticion',
	'bouton_radio_petition_activee' => 'Peticion activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreiça dau vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Minga de signatura non correspònde a aqueu còde...', # MODIF
	'form_pet_confirmation' => 'Vorgatz confirmar la vòstra signatura:',
	'form_pet_deja_signe' => 'Avètz ja signat aqueu tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Aüra recebretz un e-mail de confirmacion. Per validar la vòstra signatura, cau vesitar l’adreiça web mençonada per aquest corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bònjorn,

avètz demandat de signar la peticion:
@titre@.

Avètz fornit li informacions seguenti :
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la vòstra signatura, basta de vos connectar a 
 l’adreiça çai sota (senon s’escamparà
 la vòstra demanda): 
    @url@


Mercé per la vòstra participacion
',
	'form_pet_message_commentaire' => 'Un messatge, una remarca?', # MODIF
	'form_pet_nom_site2' => 'Nom dau vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, li signaturas son temporàriament arrestadi.',
	'form_pet_signature_validee' => 'La vòstra signatura es validada. Mercé!',
	'form_pet_site_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avètz indicada non es valida.',
	'form_pet_votre_email' => 'La vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Lo vòstre nom ò pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenètz un sit, o podètz marcar çai sota',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Respòsta a l’article'
);

?>
